import React, { useEffect, useRef, useState } from 'react';
import { useImmer } from 'use-immer';
import { GraphQueryResult } from '../../../data-access/store';
import { LinkType, NodeType } from './Types';
import { MatrixPixi } from './components/MatrixPixi';
import { VisualizationPropTypes, VISComponentType } from '../../common';
import { Input } from '@graphpolaris/shared/lib/components/inputs';
import { GraphMetaData } from '@graphpolaris/shared/lib/data-access/statistics';
import { SettingsContainer } from '@graphpolaris/shared/lib/vis/components/config';
import { dataColors, tailwindColors } from 'config';

export interface MatrixVisProps {
  marks: string;
  color: string;
}

const configuration: MatrixVisProps = {
  marks: 'rect',
  color: 'blue',
};

export const MatrixVis = React.memo(({ data, ml, configuration }: VisualizationPropTypes) => {
  const ref = useRef<HTMLDivElement>(null);
  const [graph, setGraph] = useImmer<GraphQueryResult | undefined>(undefined);
  const [highlightNodes, setHighlightNodes] = useState<NodeType[]>([]);
  const [highlightedLinks, setHighlightedLinks] = useState<LinkType[]>([]);

  useEffect(() => {
    if (data) {
      setGraph(data);
    }
  }, [data, ml]);

  return (
    <>
      <div className="h-full w-full overflow-hidden" ref={ref}>
        <MatrixPixi graph={graph} highlightNodes={highlightNodes} highlightedLinks={highlightedLinks} configuration={configuration} />
      </div>
    </>
  );
});

const MatrixSettings = ({
  configuration,
  graph,
  updateSettings,
}: {
  configuration: MatrixVisProps;
  graph: GraphMetaData;
  updateSettings: (val: any) => void;
}) => {
  return (
    <SettingsContainer>
      <Input
        type="dropdown"
        label="Configure marks"
        value={configuration.marks}
        options={['rect', 'circle']}
        onChange={(val) => updateSettings({ marks: val })}
      />

      <Input
        type="dropdown"
        label="Color"
        value={configuration.color}
        options={['blue', 'green']}
        onChange={(val) => updateSettings({ color: val })}
      />
    </SettingsContainer>
  );
};

export const MatrixVisComponent: VISComponentType = {
  displayName: 'MatrixVis',
  component: MatrixVis,
  settings: MatrixSettings,
  configuration: configuration,
};

export default MatrixVisComponent;
