import React from 'react';
import { graphQueryResultSlice, querybuilderSlice, schemaSlice, setSchema, visualizationSlice } from '../../../data-access/store';
import { configureStore } from '@reduxjs/toolkit';
import { Meta } from '@storybook/react';
import { Provider } from 'react-redux';
import { SchemaUtils } from '../../../schema/schema-utils';
import {
  bigMockQueryResults,
  big2ndChamberSchemaRaw,
  big2ndChamberQueryResult,
  marieBoucherSampleSchemaRaw,
  marieBoucherSample,
  mockRecommendationsActorMovie,
} from '../../../mock-data';
import { simpleSchemaAirportRaw } from '../../../mock-data/schema/simpleAirportRaw';
import PaohVisComponent from './paohvis';

const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
    visualize: visualizationSlice.reducer,
    querybuilder: querybuilderSlice.reducer,
  },
});

const Component: Meta<typeof PaohVisComponent.component> = {
  title: 'Visualizations/Paohvis',
  component: PaohVisComponent.component,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

export const TestWithData = {
  args: {
    data: {
      nodes: [
        { id: '1/a', label: 'a', attributes: { a: 's1' } },
        { id: '1/b1', label: 'b1', attributes: { a: 's1' } },
        { id: '1/b2', label: 'b2', attributes: { a: 's1' } },
        { id: '1/b3', label: 'b3', attributes: { a: 's1' } },
      ],
      edges: [
        { id: '1c/z1', label: 'z1', from: '1/b1', to: '1/a', attributes: { a: 's1' } },
        { id: '1c/z2', label: 'z2', from: '1/a', to: '1/b1', attributes: { a: 's1' } },
        { id: '1c/z3', label: 'z3', from: '1/b2', to: '1/b3', attributes: { a: 's2' } },
      ],
    },
    configuration: PaohVisComponent.configuration,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    const schema = SchemaUtils.schemaBackend2Graphology({
      nodes: [
        {
          name: '1',
          attributes: [{ name: 'a', type: 'string' }],
        },
      ],
      edges: [
        {
          name: '12',
          label: '12',
          from: '1',
          to: '1',
          collection: '1c',
          attributes: [{ name: 'a', type: 'string' }],
        },
      ],
    });
    dispatch(setSchema(schema.export()));
  },
};

export const TestWithMarieBoucherSample = {
  args: {
    data: marieBoucherSample,
    configuration: PaohVisComponent.configuration,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    const schema = SchemaUtils.schemaBackend2Graphology(marieBoucherSampleSchemaRaw);
    dispatch(setSchema(schema.export()));
  },
};

export const TestWithBig2ndChamber = {
  args: {
    data: big2ndChamberQueryResult,
    configuration: PaohVisComponent.configuration,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    const schema = SchemaUtils.schemaBackend2Graphology(big2ndChamberSchemaRaw);
    dispatch(setSchema(schema.export()));
  },
};

export const TestWithAirport = {
  args: {
    data: bigMockQueryResults,
    configuration: PaohVisComponent.configuration,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    const schema = SchemaUtils.schemaBackend2Graphology(simpleSchemaAirportRaw);
    dispatch(setSchema(schema.export()));
  },
};

export const TestWithRecommendationsActorMovie = {
  args: {
    data: mockRecommendationsActorMovie,
    configuration: PaohVisComponent.configuration,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    const schema = SchemaUtils.schemaBackend2Graphology(marieBoucherSampleSchemaRaw);
    dispatch(setSchema(schema.export()));
  },
};

export default Component;
